<?php
/**
 * Comments.php
 * The template for displaying Comments.
 * @package WordPress
 * @subpackage sectox
 * @subpackage sectox 1.0
 */
?>

<?php
    /*
     * If the current post is protected by a password and
     * the visitor has not yet entered the password we will
     * return early without loading the comments.
     */
    if ( post_password_required() )
        return;
?>

<!-- Comments -->
<?php if ( comments_open() || have_comments() ) : ?>
<div class="post-comments">
<?php endif; ?>

    <?php if ( have_comments() ){ ?>
        <div class="postbox__comment mb-65 post-comments-list">
            <h3 class="postbox__comment-title">
            <?php
                printf( _n( 'One thought on &ldquo;%2$s&rdquo;', '%1$s thoughts on &ldquo;%2$s&rdquo;', get_comments_number(), 'sectox' ),
                    number_format_i18n( get_comments_number() ),  ''. get_the_title() .''  );
            ?>
            </h3>
            <?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // are there comments to navigate through ?>
            <nav role="navigation" id="comment-nav-above" class="site-navigation comment-navigation">
                <h3 class="assistive-text"><?php esc_html_e( 'Comment navigation', 'sectox' ); ?></h3>
                <div class="nav-previous"><?php previous_comments_link( esc_html__( '&larr; Older Comments', 'sectox' ) ); ?></div>
                <div class="nav-next"><?php next_comments_link( esc_html__( 'Newer Comments &rarr;', 'sectox' ) ); ?></div>
            </nav><!-- #comment-nav-before .site-navigation .comment-navigation -->
            <?php endif; // check for comment navigation ?>


            <div class="latest-comments">
                <ul class="comment-list p-0 list-none">
                <?php
                    /* Loop through and list the comments. Tell wp_list_comments()
                     * to use sectox_comment() to format the comments.
                     * If you want to overload this in a child theme then you can
                     * define sectox_comment() and that will be used instead.
                     * See sectox_comment() in inc/template-tags.php for more.
                     */
                    wp_list_comments( array( 'callback' => 'sectox_comment' ) );
                ?>
                </ul>
            </div>

            <!-- .commentlist -->

            <?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // are there comments to navigate through ?>
            <nav role="navigation" id="comment-nav-below" class="site-navigation comment-navigation">
                <h3 class="assistive-text"><?php esc_html_e( 'Comment navigation', 'sectox' ); ?></h3>
                <div class="nav-previous"><?php previous_comments_link( esc_html__( '&larr; Older Comments', 'sectox' ) ); ?></div>
                <div class="nav-next"><?php next_comments_link( esc_html__( 'Newer Comments &rarr;', 'sectox' ) ); ?></div>
            </nav> 
            <?php endif; // check for comment navigation ?>
        </div>
    <?php } else { // have_comments() ?>
        <div class="no-comment-list"></div>
    <?php } ?>
    
    <?php
        // If comments are closed and there are comments, let's leave a little note, shall we?
        if ( ! comments_open() && '0' != get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) :
    ?>
        <p class="nocomments text-center"><?php esc_html_e( 'Comments are closed.', 'sectox' ); ?></p>
    <?php endif; ?>

    <?php if ( comments_open() ) : ?>
         
        <?php if ( get_option('comment_registration') && !is_user_logged_in() ) : ?>
        <p class="alert"><?php esc_html_e('You must be','sectox'); ?> <a href="<?php echo wp_login_url( get_permalink() ); ?>"><?php esc_html_e('logged in','sectox'); ?></a> <?php esc_html_e('to post a comment.','sectox'); ?></p>
        <?php else : ?>
            <div class="post-comments-form postbox__comment-form">
                <?php
                $post_id = '';
                if ( null === $post_id )
                    $post_id = get_the_ID();
                else
                    $id      = $post_id;

                $commenter       = wp_get_current_commenter();
                $user            = wp_get_current_user();
                $user_identity   = $user->exists() ? $user->display_name : '';


                $req         = get_option( 'require_name_email' );
                $aria_req    = ( $req ? " aria-required='true'" : '' );

                $fields = array(
                    'author' => '<div class="row"><div class="col-md-6"><div class="postbox__comment-input"><input placeholder="'.  esc_attr__('Enter Name', 'sectox').'" id="author" class="tp-form-control" name="author" type="text" value="' . esc_attr( $commenter[ 'comment_author' ] ) . '" size="30"' . $aria_req . ' /></div></div>',
                    'email'  => '<div class="col-md-6"><div class="postbox__comment-input"><input placeholder="'.  esc_attr__('Enter Email', 'sectox').'" id="email" name="email" class="tp-form-control" type="email" value="' . esc_attr( $commenter[ 'comment_author_email' ] ) . '" size="30"' . $aria_req . ' /></div></div>',
                    'url'    => '<div class="col-md-12"><div class="postbox__comment-input"><input placeholder="'.  esc_attr__('Enter Website', 'sectox').'" id="url" name="url" class="tp-form-control" type="url" value="' . esc_attr( $commenter[ 'comment_author_url' ] ) . '" size="30" /></div></div></div>'
                );

                if ( is_user_logged_in() ) {
                    $cl = 'loginformuser';
                } else {
                    $cl = '';
                }
                $defaults = [
                    'fields'             => $fields,
                    'comment_field'      => '
                        <div class="row postbox__comment-input">
                            <div class="col-md-12 ' . $cl . '">
                                <div class="post-input"><textarea class="tp-form-control msg-box" placeholder="'.  esc_attr__('Enter Your Comments', 'sectox').'" id="comment" name="comment" cols="45" rows="8" aria-required="true"></textarea>
                            </div></div>
                            <div class="clearfix"></div>
                        </div>
                    ',
                    'submit_button'    => '<div class="col-xl-12"><button class="tp-btn" type="submit">' . esc_html__( 'Post Comment', 'sectox' ) . ' </button></div>',
                    /** This filter is documented in wp-includes/link-template.php */
                    'must_log_in'        => '
                        <p class="must-log-in">
                        '.esc_html__('You must be','sectox').' <a href="'.esc_url(wp_login_url( apply_filters( 'the_permalink', get_permalink( $post_id ) ) )).'">'.esc_html__('logged in','sectox').'</a> '.esc_html__('to post a comment.','sectox').'
                        </p>',
                    /** This filter is documented in wp-includes/link-template.php */
                    'logged_in_as'       => '
                        <p class="logged-in-as">
                        '.esc_html__('Logged in as','sectox').' <a href="'.esc_url(get_edit_user_link()).'">'.esc_html($user_identity).'</a>. <a href="'.esc_url(wp_logout_url( apply_filters( 'the_permalink', get_permalink( $post_id ) ) )).'" title="'.esc_attr__('Log out of this account','sectox').'">'.esc_html__('Log out?','sectox').'</a>
                        </p>',
                    'id_form'            => 'commentform',
                    'id_submit'          => 'submit',
                    'class_submit'       => 'tp-btn',
                    'title_reply'        => esc_html__( 'Leave a Reply', 'sectox' ),
                    'title_reply_to'     => esc_html__( 'Leave a Reply to %s', 'sectox' ),
                    'cancel_reply_link'  => esc_html__( 'Cancel reply', 'sectox' ),
                    'label_submit'       => esc_html__( 'Post Comment', 'sectox' ),
                    'format'             => 'xhtml',
                ];

                comment_form( $defaults );
                ?>
            </div>
        <?php endif; // If registration required and not logged in ?>
        
     
    <?php endif; // if you delete this the sky will fall on your head ?>
    
<?php if ( comments_open() || have_comments() ) : ?>
</div>
<?php endif; ?>
    <!-- Comments -->