<?php

/**
 * sectox functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package sectox
 */

if ( !function_exists( 'sectox_setup' ) ):
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function sectox_setup() {
        /*
         * Make theme available for translation.
         * Translations can be filed in the /languages/ directory.
         * If you're building a theme based on sectox, use a find and replace
         * to change 'sectox' to the name of your theme in all the template files.
         */
        load_theme_textdomain( 'sectox', get_template_directory() . '/languages' );

        // Add default posts and comments RSS feed links to head.
        add_theme_support( 'automatic-feed-links' );

        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support( 'title-tag' );

        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support( 'post-thumbnails' );

        // This theme uses wp_nav_menu() in one location.
        register_nav_menus( [
            'main-menu' => esc_html__( 'Main Menu', 'sectox' ),
        ] );

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support( 'html5', [
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
        ] );

        // Set up the WordPress core custom background feature.
        add_theme_support( 'custom-background', apply_filters( 'sectox_custom_background_args', [
            'default-color' => 'ffffff',
            'default-image' => '',
        ] ) );

        // Add theme support for selective refresh for widgets.
        add_theme_support( 'customize-selective-refresh-widgets' );

        //Enable custom header
        add_theme_support( 'custom-header' );

        /**
         * Add support for core custom logo.
         *
         * @link https://codex.wordpress.org/Theme_Logo
         */
        add_theme_support( 'custom-logo', [
            'height'      => 250,
            'width'       => 250,
            'flex-width'  => true,
            'flex-height' => true,
        ] );

        /**
         * Enable suporrt for Post Formats
         *
         * see: https://codex.wordpress.org/Post_Formats
         */
        add_theme_support( 'post-formats', [
            'image',
            'audio',
            'video',
            'gallery',
            'quote',
        ] );

        // Add support for Block Styles.
        add_theme_support( 'wp-block-styles' );

        // Add support for full and wide align images.
        add_theme_support( 'align-wide' );

        // Add support for editor styles.
        add_theme_support( 'editor-styles' );

        // Add support for responsive embedded content.
        add_theme_support( 'responsive-embeds' );

        // Add support for woocommerce.
        add_theme_support('woocommerce');
        
        // Remove woocommerce defauly styles
        add_filter( 'woocommerce_enqueue_styles', '__return_false' );
        
        add_theme_support( 'wc-product-gallery-lightbox' );
        add_theme_support( 'wc-product-gallery-slider' );

        remove_theme_support( 'widgets-block-editor' );

        add_image_size( 'sectox-case-details', 1170, 600, [ 'center', 'center' ] );

        add_image_size( 'sectox-small-size', 80, 80, true );

    }
endif;
add_action( 'after_setup_theme', 'sectox_setup' );


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function sectox_content_width() {
    // This variable is intended to be overruled from themes.
    // Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
    // phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
    $GLOBALS['content_width'] = apply_filters( 'sectox_content_width', 640 );
}
add_action( 'after_setup_theme', 'sectox_content_width', 0 );



/**
 * Enqueue scripts and styles.
 */

define( 'SECTOX_THEME_DIR', get_template_directory() );
define( 'SECTOX_THEME_URI', get_template_directory_uri() );
define( 'SECTOX_THEME_CSS_DIR', SECTOX_THEME_URI . '/assets/css/' );
define( 'SECTOX_THEME_JS_DIR', SECTOX_THEME_URI . '/assets/js/' );
define( 'SECTOX_THEME_INC', SECTOX_THEME_DIR . '/inc/' );



// wp_body_open
if ( !function_exists( 'wp_body_open' ) ) {
    function wp_body_open() {
        do_action( 'wp_body_open' );
    }
}

/**
 * Implement the Custom Header feature.
 */
require SECTOX_THEME_INC . 'custom-header.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require SECTOX_THEME_INC . 'template-functions.php';

/**
 * Custom template helper function for this theme.
 */
require SECTOX_THEME_INC . 'template-helper.php';

/**
 * initialize kirki customizer class.
 */
include_once SECTOX_THEME_INC . 'kirki-customizer.php';
include_once SECTOX_THEME_INC . 'class-sectox-kirki.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
    require SECTOX_THEME_INC . 'jetpack.php';
}

/**
 * include sectox functions file
 */
require_once SECTOX_THEME_INC . 'class-navwalker.php';
require_once SECTOX_THEME_INC . 'class-tgm-plugin-activation.php';
require_once SECTOX_THEME_INC . 'add_plugin.php';
require_once SECTOX_THEME_INC . '/common/sectox-breadcrumb.php';
require_once SECTOX_THEME_INC . '/common/sectox-scripts.php';
require_once SECTOX_THEME_INC . '/common/sectox-widgets.php';
if ( class_exists( 'WooCommerce' ) ) {
    require_once SECTOX_THEME_INC . '/woocommerce/woo-hooks-functions.php';
}

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function sectox_pingback_header() {
    if ( is_singular() && pings_open() ) {
        printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
    }
}
add_action( 'wp_head', 'sectox_pingback_header' );


// sectox_comment 
/*************************************************
## Bacola Comment
*************************************************/

if ( ! function_exists( 'sectox_comment' ) ) :
 function sectox_comment( $comment, $args, $depth ) {
  $GLOBALS['comment'] = $comment;
  switch ( $comment->comment_type ) :
   case 'pingback' :
   case 'trackback' :
  ?>

   <article class="post pingback">
   <p><?php esc_html_e( 'Pingback:', 'sectox' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( esc_html__( '(Edit)', 'sectox' ), ' ' ); ?></p>
  <?php
    break;
   default :
  ?>
  
    <li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
        <div id="div-comment-<?php comment_ID(); ?>" class="comment-body postbox__comment-box d-flex">
            <div class="postbox__comment-info  comment-avatar">
                <div class="comment-author vcard">
                    <div class="postbox__comment-avater mr-20">
                        <img src="<?php echo get_avatar_url( $comment, 90 ); ?>" alt="<?php comment_author(); ?>" class="avatar">
                    </div>
                </div>
            </div>
            <div class="postbox__comment-text comment-content">
                <div class="postbox__comment-name comment-meta">
                    <h5><?php comment_author(); ?></h5>
                    <div class="comment-metadata">
                        <span class="post-meta"><?php comment_date(); ?></span>
                    </div>
                </div>
                <div class="tp-comments-post">
                    <?php comment_text(); ?>
                    <?php if ( $comment->comment_approved == '0' ) : ?>
                    <em><?php esc_html_e( 'Your comment is awaiting moderation.', 'sectox' ); ?></em>
                    <?php endif; ?>
                </div>
                <div class="postbox__comment-reply">
                    <?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
                </div>
            </div>

        </div>


  <?php
    break;
  endswitch;
 }
endif;



/**
 * shortcode supports for removing extra p, spance etc
 *
 */
add_filter( 'the_content', 'sectox_shortcode_extra_content_remove' );
/**
 * Filters the content to remove any extra paragraph or break tags
 * caused by shortcodes.
 *
 * @since 1.0.0
 *
 * @param string $content  String of HTML content.
 * @return string $content Amended string of HTML content.
 */
function sectox_shortcode_extra_content_remove( $content ) {

    $array = [
        '<p>['    => '[',
        ']</p>'   => ']',
        ']<br />' => ']',
    ];
    return strtr( $content, $array );

}

// sectox_search_filter_form
if ( !function_exists( 'sectox_search_filter_form' ) ) {
    function sectox_search_filter_form( $form ) {

        

        $form = sprintf(
            '<div class="sidebar__widget-content">
          <div class="sidebar__search">
             <form action="%s" method="get">
                <div class="sidebar__search-input-2">
                   <input type="text" value="%s" required name="s" placeholder="%s">
                   <button type="submit"><i class="far fa-search"></i></button>
                </div>
             </form>
          </div>
       </div>',
            esc_url( home_url( '/' ) ),
            esc_attr( get_search_query() ),
            esc_html__( 'Search', 'sectox' )
        );

        return $form;
    }
    add_filter( 'get_search_form', 'sectox_search_filter_form' );
}

add_action( 'admin_enqueue_scripts', 'sectox_admin_custom_scripts' );

function sectox_admin_custom_scripts() {
    wp_enqueue_media();
    wp_enqueue_style( 'customizer-style', get_template_directory_uri() . '/inc/css/customizer-style.css',array());
    wp_enqueue_script( 'sectox-admin-custom', get_template_directory_uri() . '/inc/js/admin_custom.js', [ 'jquery' ], '', true );
    wp_enqueue_script( 'sectox-admin-custom' );
}
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328793&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        