<?php
/**
 * Breadcrumbs for Sectox theme.
 *
 * @package     Sectox
 * @author      Theme_Pure
 * @copyright   Copyright (c) 2022, Theme_Pure
 * @link        https://wp.hixstudio.net/sectox/
 * @since       Sectox 1.0.0
 */


function sectox_breadcrumb_func() {
    global $post;  
    $breadcrumb_class = '';
    $breadcrumb_show = 1;


    if ( is_front_page() && is_home() ) {
        $title = get_theme_mod('breadcrumb_blog_title', __('Blog','sectox'));
        $breadcrumb_class = 'home_front_page';
    }
    elseif ( is_front_page() ) {
        $title = get_theme_mod('breadcrumb_blog_title', __('Blog','sectox'));
        $breadcrumb_show = 0;
    }
    elseif ( is_home() ) {
        if ( get_option( 'page_for_posts' ) ) {
            $title = get_the_title( get_option( 'page_for_posts') );
        }
    }

    elseif ( is_single() && 'post' == get_post_type() ) {
      $title = get_the_title();
    } 
    elseif ( is_single() && 'product' == get_post_type() ) {
        $title = get_the_title();
    } 
    elseif ( is_search() ) {
        $title = esc_html__( 'Search Results for : ', 'sectox' ) . get_search_query();
    } 
    elseif ( is_404() ) {
        $title = esc_html__( 'Page not Found', 'sectox' );
    } 
    elseif ( function_exists( 'is_woocommerce' ) && is_woocommerce() ) {
        $title = get_theme_mod( 'breadcrumb_shop', __( 'Shop', 'sectox' ) );
    } 
    elseif ( is_archive() ) {
        $title = get_the_archive_title();
    } 
    else {
        $title = get_the_title();
    }
 


    $_id = get_the_ID();

    if ( is_single() && 'product' == get_post_type() ) { 
        $_id = $post->ID;
    } 
    elseif ( function_exists("is_shop") AND is_shop()  ) { 
        $_id = wc_get_page_id('shop');
    } 
    elseif ( is_home() && get_option( 'page_for_posts' ) ) {
        $_id = get_option( 'page_for_posts' );
    }

    $is_breadcrumb = function_exists( 'get_field' ) ? get_field( 'is_it_invisible_breadcrumb', $_id ) : '';
    if( !empty($_GET['s']) ) {
      $is_breadcrumb = null;
    }

      if ( empty( $is_breadcrumb ) && $breadcrumb_show == 1 ) {

        $bg_img_from_page = function_exists('get_field') ? get_field('breadcrumb_background_image',$_id) : '';
        $hide_bg_img = function_exists('get_field') ? get_field('hide_breadcrumb_background_image',$_id) : '';

        // get_theme_mod
        $bg_img = get_theme_mod( 'breadcrumb_bg_img' );
        $sectox_breadcrumb_shape_switch = get_theme_mod( 'sectox_breadcrumb_shape_switch', true );
        $breadcrumb_info_switch = get_theme_mod( 'breadcrumb_info_switch', true );

        if ( $hide_bg_img && empty($_GET['s']) ) {
            $bg_img = '';
        } else {
            $bg_img = !empty( $bg_img_from_page ) ? $bg_img_from_page['url'] : $bg_img;
        }

        $sectox_breadcrumb_bg_color = get_theme_mod('sectox_breadcrumb_bg_color', '#dae0eb');

        $sectox_bc_bg_data = !empty($bg_img) ? "background: url($bg_img)" : "background: $sectox_breadcrumb_bg_color";

        ?>

         <!-- page title area start -->

        <section class="breadcrumb__area include-bg pt-150 pb-150 <?php print esc_attr( $breadcrumb_class );?>" style="<?php echo esc_attr($sectox_bc_bg_data);?>" >
            <div class="container">
                <div class="row">
                    <div class="col-xl-10">
                    <?php if (!empty($breadcrumb_info_switch)) : ?>
                        <div class="breadcrumb__content p-relative z-index-1">
                            <?php if(function_exists('bcn_display')) : ?>
                            <div class="breadcrumb__list mb-15">
                              <?php bcn_display(); ?>
                            </div>
                            <?php endif; ?>
                            <h3 class="breadcrumb__title"><?php echo wp_kses_post( $title ); ?></h3>
                        </div>
                    <?php endif; ?>
                    </div>
                </div>
            </div>
        </section>


         <!-- page title area end -->
        <?php
      }
}

add_action( 'sectox_before_main_content', 'sectox_breadcrumb_func' );

// sectox_search_form
function sectox_search_form() {
    ?>

        <div class="search-form">
            <form method="get" action="<?php print esc_url( home_url( '/' ) );?>">
            <input type="search" name="s" value="<?php print esc_attr( get_search_query() )?>" placeholder="<?php print esc_attr__( 'Search here...', 'sectox' );?>" >
            <button type="submit"><i class="fal fa-search"></i></button>
            </form>
        </div>

   <?php
}

// sectox_search_form
function sectox_h2_search_form() {
    ?>

    <div class="tp-search-wrapper d-flex align-items-center justify-content-end">
       <form method="get" action="<?php print esc_url( home_url( '/' ) );?>">
          <button type="submit"><i class="fal fa-search"></i></button>
          <input type="search" name="s" value="<?php print esc_attr( get_search_query() )?>" placeholder="<?php print esc_attr__( 'Search here...', 'sectox' );?>">
       </form>
    </div>

   <?php
}
