<?php 

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function sectox_widgets_init() {

    $footer_style_2_switch = get_theme_mod( 'footer_style_2_switch', true );
    $footer_style_3_switch = get_theme_mod( 'footer_style_3_switch', true );

    /**
     * blog sidebar
     */
    register_sidebar( [
        'name'          => esc_html__( 'Blog Sidebar', 'sectox' ),
        'id'            => 'blog-sidebar',
        'description'          => esc_html__( 'Set Your Blog Widget', 'sectox' ),
        'before_widget' => '<div id="%1$s" class="sidebar__widget mb-40 %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h3 class="sidebar__widget-title">',
        'after_title'   => '</h3>',
    ] );

    // product sidebar
    register_sidebar(array(
        'name' => esc_html__('Product Sidebar', 'sectox'),
        'id' => 'product-sidebar',
        'before_widget' => '<div id="%1$s" class="product-sidebar %2$s mb-45">',
        'after_widget' => '</div>',
        'before_title' => '<h3 class="product__widget-title">',
        'after_title' => '</h3>',
    ));

    // portfolio sidebar
    register_sidebar( [
        'name'          => esc_html__( 'Portfolio & Service Sidebar', 'sectox' ),
        'id'            => 'portfolio-sidebar',
        'description'          => esc_html__( 'Set Your portfolio Widget', 'sectox' ),
        'before_widget' => '<div id="%1$s" class="tp-sidebar-widget pb-50 %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h4 class="tp-widget-title">',
        'after_title'   => '</h4>',
    ] );


    $footer_widgets = get_theme_mod( 'footer_widget_number', 4 );

    // footer default
    for ( $num = 1; $num <= $footer_widgets; $num++ ) {
        register_sidebar( [
            'name'          => sprintf( esc_html__( 'Footer %1$s', 'sectox' ), $num ),
            'id'            => 'footer-' . $num,
            'description'   => sprintf( esc_html__( 'Footer column %1$s', 'sectox' ), $num ),
            'before_widget' => '<div id="%1$s" class="footer-widget mb-50 footer-col-'.$num.' %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h3 class="footer-widget-title">',
            'after_title'   => '</h3>',
        ] );
    }

    // footer 2
    if ( $footer_style_2_switch ) {
        for ( $num = 1; $num <= $footer_widgets; $num++ ) {

            register_sidebar( [
                'name'          => sprintf( esc_html__( 'Footer Style 2 : %1$s', 'sectox' ), $num ),
                'id'            => 'footer-2-' . $num,
                'description'   => sprintf( esc_html__( 'Footer Style 2 : %1$s', 'sectox' ), $num ),
                'before_widget' => '<div id="%1$s" class="footer-widget footer-widget-2 footer-col-2-'.$num.' mb-50 %2$s">',
                'after_widget'  => '</div>',
                'before_title'  => '<h3 class="footer-widget-title">',
                'after_title'   => '</h3>',
            ] );
        }
    } 

    // footer 3
    if ( $footer_style_3_switch ) {
        for ( $num = 1; $num <= $footer_widgets; $num++ ) {

            register_sidebar( [
                'name'          => sprintf( esc_html__( 'Footer Style 3 : %1$s', 'sectox' ), $num ),
                'id'            => 'footer-3-' . $num,
                'description'   => sprintf( esc_html__( 'Footer Style 3 : %1$s', 'sectox' ), $num ),
                'before_widget' => '<div id="%1$s" class="footer-widget footer-widget-3 footer-col-3-'.$num.' mb-50 %2$s">',
                'after_widget'  => '</div>',
                'before_title'  => '<h3 class="footer-widget-title">',
                'after_title'   => '</h3>',
            ] );
        }
    }    

}
add_action( 'widgets_init', 'sectox_widgets_init' );